/***************************************************************************//**
* \file UARTdbg.c
* \version 4.0
*
* \brief
*  This file provides the source code to the API for the SCB Component.
*
* Note:
*
*******************************************************************************
* \copyright
* Copyright 2013-2017, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "UARTdbg_PVT.h"

#if (UARTdbg_SCB_MODE_I2C_INC)
    #include "UARTdbg_I2C_PVT.h"
#endif /* (UARTdbg_SCB_MODE_I2C_INC) */

#if (UARTdbg_SCB_MODE_EZI2C_INC)
    #include "UARTdbg_EZI2C_PVT.h"
#endif /* (UARTdbg_SCB_MODE_EZI2C_INC) */

#if (UARTdbg_SCB_MODE_SPI_INC || UARTdbg_SCB_MODE_UART_INC)
    #include "UARTdbg_SPI_UART_PVT.h"
#endif /* (UARTdbg_SCB_MODE_SPI_INC || UARTdbg_SCB_MODE_UART_INC) */


/***************************************
*    Run Time Configuration Vars
***************************************/

/* Stores internal component configuration for Unconfigured mode */
#if (UARTdbg_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Common configuration variables */
    uint8 UARTdbg_scbMode = UARTdbg_SCB_MODE_UNCONFIG;
    uint8 UARTdbg_scbEnableWake;
    uint8 UARTdbg_scbEnableIntr;

    /* I2C configuration variables */
    uint8 UARTdbg_mode;
    uint8 UARTdbg_acceptAddr;

    /* SPI/UART configuration variables */
    volatile uint8 * UARTdbg_rxBuffer;
    uint8  UARTdbg_rxDataBits;
    uint32 UARTdbg_rxBufferSize;

    volatile uint8 * UARTdbg_txBuffer;
    uint8  UARTdbg_txDataBits;
    uint32 UARTdbg_txBufferSize;

    /* EZI2C configuration variables */
    uint8 UARTdbg_numberOfAddr;
    uint8 UARTdbg_subAddrSize;
#endif /* (UARTdbg_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*     Common SCB Vars
***************************************/
/**
* \addtogroup group_general
* \{
*/

/** UARTdbg_initVar indicates whether the UARTdbg 
*  component has been initialized. The variable is initialized to 0 
*  and set to 1 the first time SCB_Start() is called. This allows 
*  the component to restart without reinitialization after the first 
*  call to the UARTdbg_Start() routine.
*
*  If re-initialization of the component is required, then the 
*  UARTdbg_Init() function can be called before the 
*  UARTdbg_Start() or UARTdbg_Enable() function.
*/
uint8 UARTdbg_initVar = 0u;


#if (! (UARTdbg_SCB_MODE_I2C_CONST_CFG || \
        UARTdbg_SCB_MODE_EZI2C_CONST_CFG))
    /** This global variable stores TX interrupt sources after 
    * UARTdbg_Stop() is called. Only these TX interrupt sources 
    * will be restored on a subsequent UARTdbg_Enable() call.
    */
    uint16 UARTdbg_IntrTxMask = 0u;
#endif /* (! (UARTdbg_SCB_MODE_I2C_CONST_CFG || \
              UARTdbg_SCB_MODE_EZI2C_CONST_CFG)) */
/** \} globals */

#if (UARTdbg_SCB_IRQ_INTERNAL)
#if !defined (CY_REMOVE_UARTdbg_CUSTOM_INTR_HANDLER)
    void (*UARTdbg_customIntrHandler)(void) = NULL;
#endif /* !defined (CY_REMOVE_UARTdbg_CUSTOM_INTR_HANDLER) */
#endif /* (UARTdbg_SCB_IRQ_INTERNAL) */


/***************************************
*    Private Function Prototypes
***************************************/

static void UARTdbg_ScbEnableIntr(void);
static void UARTdbg_ScbModeStop(void);
static void UARTdbg_ScbModePostEnable(void);


/*******************************************************************************
* Function Name: UARTdbg_Init
****************************************************************************//**
*
*  Initializes the UARTdbg component to operate in one of the selected
*  configurations: I2C, SPI, UART or EZI2C.
*  When the configuration is set to "Unconfigured SCB", this function does
*  not do any initialization. Use mode-specific initialization APIs instead:
*  UARTdbg_I2CInit, UARTdbg_SpiInit, 
*  UARTdbg_UartInit or UARTdbg_EzI2CInit.
*
*******************************************************************************/
void UARTdbg_Init(void)
{
#if (UARTdbg_SCB_MODE_UNCONFIG_CONST_CFG)
    if (UARTdbg_SCB_MODE_UNCONFIG_RUNTM_CFG)
    {
        UARTdbg_initVar = 0u;
    }
    else
    {
        /* Initialization was done before this function call */
    }

#elif (UARTdbg_SCB_MODE_I2C_CONST_CFG)
    UARTdbg_I2CInit();

#elif (UARTdbg_SCB_MODE_SPI_CONST_CFG)
    UARTdbg_SpiInit();

#elif (UARTdbg_SCB_MODE_UART_CONST_CFG)
    UARTdbg_UartInit();

#elif (UARTdbg_SCB_MODE_EZI2C_CONST_CFG)
    UARTdbg_EzI2CInit();

#endif /* (UARTdbg_SCB_MODE_UNCONFIG_CONST_CFG) */
}


/*******************************************************************************
* Function Name: UARTdbg_Enable
****************************************************************************//**
*
*  Enables UARTdbg component operation: activates the hardware and 
*  internal interrupt. It also restores TX interrupt sources disabled after the 
*  UARTdbg_Stop() function was called (note that level-triggered TX 
*  interrupt sources remain disabled to not cause code lock-up).
*  For I2C and EZI2C modes the interrupt is internal and mandatory for 
*  operation. For SPI and UART modes the interrupt can be configured as none, 
*  internal or external.
*  The UARTdbg configuration should be not changed when the component
*  is enabled. Any configuration changes should be made after disabling the 
*  component.
*  When configuration is set to “Unconfigured UARTdbg”, the component 
*  must first be initialized to operate in one of the following configurations: 
*  I2C, SPI, UART or EZ I2C, using the mode-specific initialization API. 
*  Otherwise this function does not enable the component.
*
*******************************************************************************/
void UARTdbg_Enable(void)
{
#if (UARTdbg_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Enable SCB block, only if it is already configured */
    if (!UARTdbg_SCB_MODE_UNCONFIG_RUNTM_CFG)
    {
        UARTdbg_CTRL_REG |= UARTdbg_CTRL_ENABLED;

        UARTdbg_ScbEnableIntr();

        /* Call PostEnable function specific to current operation mode */
        UARTdbg_ScbModePostEnable();
    }
#else
    UARTdbg_CTRL_REG |= UARTdbg_CTRL_ENABLED;

    UARTdbg_ScbEnableIntr();

    /* Call PostEnable function specific to current operation mode */
    UARTdbg_ScbModePostEnable();
#endif /* (UARTdbg_SCB_MODE_UNCONFIG_CONST_CFG) */
}


/*******************************************************************************
* Function Name: UARTdbg_Start
****************************************************************************//**
*
*  Invokes UARTdbg_Init() and UARTdbg_Enable().
*  After this function call, the component is enabled and ready for operation.
*  When configuration is set to "Unconfigured SCB", the component must first be
*  initialized to operate in one of the following configurations: I2C, SPI, UART
*  or EZI2C. Otherwise this function does not enable the component.
*
* \globalvars
*  UARTdbg_initVar - used to check initial configuration, modified
*  on first function call.
*
*******************************************************************************/
void UARTdbg_Start(void)
{
    if (0u == UARTdbg_initVar)
    {
        UARTdbg_Init();
        UARTdbg_initVar = 1u; /* Component was initialized */
    }

    UARTdbg_Enable();
}


/*******************************************************************************
* Function Name: UARTdbg_Stop
****************************************************************************//**
*
*  Disables the UARTdbg component: disable the hardware and internal 
*  interrupt. It also disables all TX interrupt sources so as not to cause an 
*  unexpected interrupt trigger because after the component is enabled, the 
*  TX FIFO is empty.
*  Refer to the function UARTdbg_Enable() for the interrupt 
*  configuration details.
*  This function disables the SCB component without checking to see if 
*  communication is in progress. Before calling this function it may be 
*  necessary to check the status of communication to make sure communication 
*  is complete. If this is not done then communication could be stopped mid 
*  byte and corrupted data could result.
*
*******************************************************************************/
void UARTdbg_Stop(void)
{
#if (UARTdbg_SCB_IRQ_INTERNAL)
    UARTdbg_DisableInt();
#endif /* (UARTdbg_SCB_IRQ_INTERNAL) */

    /* Call Stop function specific to current operation mode */
    UARTdbg_ScbModeStop();

    /* Disable SCB IP */
    UARTdbg_CTRL_REG &= (uint32) ~UARTdbg_CTRL_ENABLED;

    /* Disable all TX interrupt sources so as not to cause an unexpected
    * interrupt trigger after the component will be enabled because the 
    * TX FIFO is empty.
    * For SCB IP v0, it is critical as it does not mask-out interrupt
    * sources when it is disabled. This can cause a code lock-up in the
    * interrupt handler because TX FIFO cannot be loaded after the block
    * is disabled.
    */
    UARTdbg_SetTxInterruptMode(UARTdbg_NO_INTR_SOURCES);

#if (UARTdbg_SCB_IRQ_INTERNAL)
    UARTdbg_ClearPendingInt();
#endif /* (UARTdbg_SCB_IRQ_INTERNAL) */
}


/*******************************************************************************
* Function Name: UARTdbg_SetRxFifoLevel
****************************************************************************//**
*
*  Sets level in the RX FIFO to generate a RX level interrupt.
*  When the RX FIFO has more entries than the RX FIFO level an RX level
*  interrupt request is generated.
*
*  \param level: Level in the RX FIFO to generate RX level interrupt.
*   The range of valid level values is between 0 and RX FIFO depth - 1.
*
*******************************************************************************/
void UARTdbg_SetRxFifoLevel(uint32 level)
{
    uint32 rxFifoCtrl;

    rxFifoCtrl = UARTdbg_RX_FIFO_CTRL_REG;

    rxFifoCtrl &= ((uint32) ~UARTdbg_RX_FIFO_CTRL_TRIGGER_LEVEL_MASK); /* Clear level mask bits */
    rxFifoCtrl |= ((uint32) (UARTdbg_RX_FIFO_CTRL_TRIGGER_LEVEL_MASK & level));

    UARTdbg_RX_FIFO_CTRL_REG = rxFifoCtrl;
}


/*******************************************************************************
* Function Name: UARTdbg_SetTxFifoLevel
****************************************************************************//**
*
*  Sets level in the TX FIFO to generate a TX level interrupt.
*  When the TX FIFO has less entries than the TX FIFO level an TX level
*  interrupt request is generated.
*
*  \param level: Level in the TX FIFO to generate TX level interrupt.
*   The range of valid level values is between 0 and TX FIFO depth - 1.
*
*******************************************************************************/
void UARTdbg_SetTxFifoLevel(uint32 level)
{
    uint32 txFifoCtrl;

    txFifoCtrl = UARTdbg_TX_FIFO_CTRL_REG;

    txFifoCtrl &= ((uint32) ~UARTdbg_TX_FIFO_CTRL_TRIGGER_LEVEL_MASK); /* Clear level mask bits */
    txFifoCtrl |= ((uint32) (UARTdbg_TX_FIFO_CTRL_TRIGGER_LEVEL_MASK & level));

    UARTdbg_TX_FIFO_CTRL_REG = txFifoCtrl;
}


#if (UARTdbg_SCB_IRQ_INTERNAL)
    /*******************************************************************************
    * Function Name: UARTdbg_SetCustomInterruptHandler
    ****************************************************************************//**
    *
    *  Registers a function to be called by the internal interrupt handler.
    *  First the function that is registered is called, then the internal interrupt
    *  handler performs any operation such as software buffer management functions
    *  before the interrupt returns.  It is the user's responsibility not to break
    *  the software buffer operations. Only one custom handler is supported, which
    *  is the function provided by the most recent call.
    *  At the initialization time no custom handler is registered.
    *
    *  \param func: Pointer to the function to register.
    *        The value NULL indicates to remove the current custom interrupt
    *        handler.
    *
    *******************************************************************************/
    void UARTdbg_SetCustomInterruptHandler(void (*func)(void))
    {
    #if !defined (CY_REMOVE_UARTdbg_CUSTOM_INTR_HANDLER)
        UARTdbg_customIntrHandler = func; /* Register interrupt handler */
    #else
        if (NULL != func)
        {
            /* Suppress compiler warning */
        }
    #endif /* !defined (CY_REMOVE_UARTdbg_CUSTOM_INTR_HANDLER) */
    }
#endif /* (UARTdbg_SCB_IRQ_INTERNAL) */


/*******************************************************************************
* Function Name: UARTdbg_ScbModeEnableIntr
****************************************************************************//**
*
*  Enables an interrupt for a specific mode.
*
*******************************************************************************/
static void UARTdbg_ScbEnableIntr(void)
{
#if (UARTdbg_SCB_IRQ_INTERNAL)
    /* Enable interrupt in NVIC */
    #if (UARTdbg_SCB_MODE_UNCONFIG_CONST_CFG)
        if (0u != UARTdbg_scbEnableIntr)
        {
            UARTdbg_EnableInt();
        }

    #else
        UARTdbg_EnableInt();

    #endif /* (UARTdbg_SCB_MODE_UNCONFIG_CONST_CFG) */
#endif /* (UARTdbg_SCB_IRQ_INTERNAL) */
}


/*******************************************************************************
* Function Name: UARTdbg_ScbModePostEnable
****************************************************************************//**
*
*  Calls the PostEnable function for a specific operation mode.
*
*******************************************************************************/
static void UARTdbg_ScbModePostEnable(void)
{
#if (UARTdbg_SCB_MODE_UNCONFIG_CONST_CFG)
#if (!UARTdbg_CY_SCBIP_V1)
    if (UARTdbg_SCB_MODE_SPI_RUNTM_CFG)
    {
        UARTdbg_SpiPostEnable();
    }
    else if (UARTdbg_SCB_MODE_UART_RUNTM_CFG)
    {
        UARTdbg_UartPostEnable();
    }
    else
    {
        /* Unknown mode: do nothing */
    }
#endif /* (!UARTdbg_CY_SCBIP_V1) */

#elif (UARTdbg_SCB_MODE_SPI_CONST_CFG)
    UARTdbg_SpiPostEnable();

#elif (UARTdbg_SCB_MODE_UART_CONST_CFG)
    UARTdbg_UartPostEnable();

#else
    /* Unknown mode: do nothing */
#endif /* (UARTdbg_SCB_MODE_UNCONFIG_CONST_CFG) */
}


/*******************************************************************************
* Function Name: UARTdbg_ScbModeStop
****************************************************************************//**
*
*  Calls the Stop function for a specific operation mode.
*
*******************************************************************************/
static void UARTdbg_ScbModeStop(void)
{
#if (UARTdbg_SCB_MODE_UNCONFIG_CONST_CFG)
    if (UARTdbg_SCB_MODE_I2C_RUNTM_CFG)
    {
        UARTdbg_I2CStop();
    }
    else if (UARTdbg_SCB_MODE_EZI2C_RUNTM_CFG)
    {
        UARTdbg_EzI2CStop();
    }
#if (!UARTdbg_CY_SCBIP_V1)
    else if (UARTdbg_SCB_MODE_SPI_RUNTM_CFG)
    {
        UARTdbg_SpiStop();
    }
    else if (UARTdbg_SCB_MODE_UART_RUNTM_CFG)
    {
        UARTdbg_UartStop();
    }
#endif /* (!UARTdbg_CY_SCBIP_V1) */
    else
    {
        /* Unknown mode: do nothing */
    }
#elif (UARTdbg_SCB_MODE_I2C_CONST_CFG)
    UARTdbg_I2CStop();

#elif (UARTdbg_SCB_MODE_EZI2C_CONST_CFG)
    UARTdbg_EzI2CStop();

#elif (UARTdbg_SCB_MODE_SPI_CONST_CFG)
    UARTdbg_SpiStop();

#elif (UARTdbg_SCB_MODE_UART_CONST_CFG)
    UARTdbg_UartStop();

#else
    /* Unknown mode: do nothing */
#endif /* (UARTdbg_SCB_MODE_UNCONFIG_CONST_CFG) */
}


#if (UARTdbg_SCB_MODE_UNCONFIG_CONST_CFG)
    /*******************************************************************************
    * Function Name: UARTdbg_SetPins
    ****************************************************************************//**
    *
    *  Sets the pins settings accordingly to the selected operation mode.
    *  Only available in the Unconfigured operation mode. The mode specific
    *  initialization function calls it.
    *  Pins configuration is set by PSoC Creator when a specific mode of operation
    *  is selected in design time.
    *
    *  \param mode:      Mode of SCB operation.
    *  \param subMode:   Sub-mode of SCB operation. It is only required for SPI and UART
    *             modes.
    *  \param uartEnableMask: enables TX or RX direction and RTS and CTS signals.
    *
    *******************************************************************************/
    void UARTdbg_SetPins(uint32 mode, uint32 subMode, uint32 uartEnableMask)
    {
        uint32 pinsDm[UARTdbg_SCB_PINS_NUMBER];
        uint32 i;
        
    #if (!UARTdbg_CY_SCBIP_V1)
        uint32 pinsInBuf = 0u;
    #endif /* (!UARTdbg_CY_SCBIP_V1) */
        
        uint32 hsiomSel[UARTdbg_SCB_PINS_NUMBER] = 
        {
            UARTdbg_RX_SDA_MOSI_HSIOM_SEL_GPIO,
            UARTdbg_TX_SCL_MISO_HSIOM_SEL_GPIO,
            0u,
            0u,
            0u,
            0u,
            0u,
        };

    #if (UARTdbg_CY_SCBIP_V1)
        /* Supress compiler warning. */
        if ((0u == subMode) || (0u == uartEnableMask))
        {
        }
    #endif /* (UARTdbg_CY_SCBIP_V1) */

        /* Set default HSIOM to GPIO and Drive Mode to Analog Hi-Z */
        for (i = 0u; i < UARTdbg_SCB_PINS_NUMBER; i++)
        {
            pinsDm[i] = UARTdbg_PIN_DM_ALG_HIZ;
        }

        if ((UARTdbg_SCB_MODE_I2C   == mode) ||
            (UARTdbg_SCB_MODE_EZI2C == mode))
        {
        #if (UARTdbg_RX_SDA_MOSI_PIN)
            hsiomSel[UARTdbg_RX_SDA_MOSI_PIN_INDEX] = UARTdbg_RX_SDA_MOSI_HSIOM_SEL_I2C;
            pinsDm  [UARTdbg_RX_SDA_MOSI_PIN_INDEX] = UARTdbg_PIN_DM_OD_LO;
        #elif (UARTdbg_RX_WAKE_SDA_MOSI_PIN)
            hsiomSel[UARTdbg_RX_WAKE_SDA_MOSI_PIN_INDEX] = UARTdbg_RX_WAKE_SDA_MOSI_HSIOM_SEL_I2C;
            pinsDm  [UARTdbg_RX_WAKE_SDA_MOSI_PIN_INDEX] = UARTdbg_PIN_DM_OD_LO;
        #else
        #endif /* (UARTdbg_RX_SDA_MOSI_PIN) */
        
        #if (UARTdbg_TX_SCL_MISO_PIN)
            hsiomSel[UARTdbg_TX_SCL_MISO_PIN_INDEX] = UARTdbg_TX_SCL_MISO_HSIOM_SEL_I2C;
            pinsDm  [UARTdbg_TX_SCL_MISO_PIN_INDEX] = UARTdbg_PIN_DM_OD_LO;
        #endif /* (UARTdbg_TX_SCL_MISO_PIN) */
        }
    #if (!UARTdbg_CY_SCBIP_V1)
        else if (UARTdbg_SCB_MODE_SPI == mode)
        {
        #if (UARTdbg_RX_SDA_MOSI_PIN)
            hsiomSel[UARTdbg_RX_SDA_MOSI_PIN_INDEX] = UARTdbg_RX_SDA_MOSI_HSIOM_SEL_SPI;
        #elif (UARTdbg_RX_WAKE_SDA_MOSI_PIN)
            hsiomSel[UARTdbg_RX_WAKE_SDA_MOSI_PIN_INDEX] = UARTdbg_RX_WAKE_SDA_MOSI_HSIOM_SEL_SPI;
        #else
        #endif /* (UARTdbg_RX_SDA_MOSI_PIN) */
        
        #if (UARTdbg_TX_SCL_MISO_PIN)
            hsiomSel[UARTdbg_TX_SCL_MISO_PIN_INDEX] = UARTdbg_TX_SCL_MISO_HSIOM_SEL_SPI;
        #endif /* (UARTdbg_TX_SCL_MISO_PIN) */
        
        #if (UARTdbg_CTS_SCLK_PIN)
            hsiomSel[UARTdbg_CTS_SCLK_PIN_INDEX] = UARTdbg_CTS_SCLK_HSIOM_SEL_SPI;
        #endif /* (UARTdbg_CTS_SCLK_PIN) */

            if (UARTdbg_SPI_SLAVE == subMode)
            {
                /* Slave */
                pinsDm[UARTdbg_RX_SDA_MOSI_PIN_INDEX] = UARTdbg_PIN_DM_DIG_HIZ;
                pinsDm[UARTdbg_TX_SCL_MISO_PIN_INDEX] = UARTdbg_PIN_DM_STRONG;
                pinsDm[UARTdbg_CTS_SCLK_PIN_INDEX] = UARTdbg_PIN_DM_DIG_HIZ;

            #if (UARTdbg_RTS_SS0_PIN)
                /* Only SS0 is valid choice for Slave */
                hsiomSel[UARTdbg_RTS_SS0_PIN_INDEX] = UARTdbg_RTS_SS0_HSIOM_SEL_SPI;
                pinsDm  [UARTdbg_RTS_SS0_PIN_INDEX] = UARTdbg_PIN_DM_DIG_HIZ;
            #endif /* (UARTdbg_RTS_SS0_PIN) */

            #if (UARTdbg_TX_SCL_MISO_PIN)
                /* Disable input buffer */
                 pinsInBuf |= UARTdbg_TX_SCL_MISO_PIN_MASK;
            #endif /* (UARTdbg_TX_SCL_MISO_PIN) */
            }
            else 
            {
                /* (Master) */
                pinsDm[UARTdbg_RX_SDA_MOSI_PIN_INDEX] = UARTdbg_PIN_DM_STRONG;
                pinsDm[UARTdbg_TX_SCL_MISO_PIN_INDEX] = UARTdbg_PIN_DM_DIG_HIZ;
                pinsDm[UARTdbg_CTS_SCLK_PIN_INDEX] = UARTdbg_PIN_DM_STRONG;

            #if (UARTdbg_RTS_SS0_PIN)
                hsiomSel [UARTdbg_RTS_SS0_PIN_INDEX] = UARTdbg_RTS_SS0_HSIOM_SEL_SPI;
                pinsDm   [UARTdbg_RTS_SS0_PIN_INDEX] = UARTdbg_PIN_DM_STRONG;
                pinsInBuf |= UARTdbg_RTS_SS0_PIN_MASK;
            #endif /* (UARTdbg_RTS_SS0_PIN) */

            #if (UARTdbg_SS1_PIN)
                hsiomSel [UARTdbg_SS1_PIN_INDEX] = UARTdbg_SS1_HSIOM_SEL_SPI;
                pinsDm   [UARTdbg_SS1_PIN_INDEX] = UARTdbg_PIN_DM_STRONG;
                pinsInBuf |= UARTdbg_SS1_PIN_MASK;
            #endif /* (UARTdbg_SS1_PIN) */

            #if (UARTdbg_SS2_PIN)
                hsiomSel [UARTdbg_SS2_PIN_INDEX] = UARTdbg_SS2_HSIOM_SEL_SPI;
                pinsDm   [UARTdbg_SS2_PIN_INDEX] = UARTdbg_PIN_DM_STRONG;
                pinsInBuf |= UARTdbg_SS2_PIN_MASK;
            #endif /* (UARTdbg_SS2_PIN) */

            #if (UARTdbg_SS3_PIN)
                hsiomSel [UARTdbg_SS3_PIN_INDEX] = UARTdbg_SS3_HSIOM_SEL_SPI;
                pinsDm   [UARTdbg_SS3_PIN_INDEX] = UARTdbg_PIN_DM_STRONG;
                pinsInBuf |= UARTdbg_SS3_PIN_MASK;
            #endif /* (UARTdbg_SS3_PIN) */

                /* Disable input buffers */
            #if (UARTdbg_RX_SDA_MOSI_PIN)
                pinsInBuf |= UARTdbg_RX_SDA_MOSI_PIN_MASK;
            #elif (UARTdbg_RX_WAKE_SDA_MOSI_PIN)
                pinsInBuf |= UARTdbg_RX_WAKE_SDA_MOSI_PIN_MASK;
            #else
            #endif /* (UARTdbg_RX_SDA_MOSI_PIN) */

            #if (UARTdbg_CTS_SCLK_PIN)
                pinsInBuf |= UARTdbg_CTS_SCLK_PIN_MASK;
            #endif /* (UARTdbg_CTS_SCLK_PIN) */
            }
        }
        else /* UART */
        {
            if (UARTdbg_UART_MODE_SMARTCARD == subMode)
            {
                /* SmartCard */
            #if (UARTdbg_TX_SCL_MISO_PIN)
                hsiomSel[UARTdbg_TX_SCL_MISO_PIN_INDEX] = UARTdbg_TX_SCL_MISO_HSIOM_SEL_UART;
                pinsDm  [UARTdbg_TX_SCL_MISO_PIN_INDEX] = UARTdbg_PIN_DM_OD_LO;
            #endif /* (UARTdbg_TX_SCL_MISO_PIN) */
            }
            else /* Standard or IrDA */
            {
                if (0u != (UARTdbg_UART_RX_PIN_ENABLE & uartEnableMask))
                {
                #if (UARTdbg_RX_SDA_MOSI_PIN)
                    hsiomSel[UARTdbg_RX_SDA_MOSI_PIN_INDEX] = UARTdbg_RX_SDA_MOSI_HSIOM_SEL_UART;
                    pinsDm  [UARTdbg_RX_SDA_MOSI_PIN_INDEX] = UARTdbg_PIN_DM_DIG_HIZ;
                #elif (UARTdbg_RX_WAKE_SDA_MOSI_PIN)
                    hsiomSel[UARTdbg_RX_WAKE_SDA_MOSI_PIN_INDEX] = UARTdbg_RX_WAKE_SDA_MOSI_HSIOM_SEL_UART;
                    pinsDm  [UARTdbg_RX_WAKE_SDA_MOSI_PIN_INDEX] = UARTdbg_PIN_DM_DIG_HIZ;
                #else
                #endif /* (UARTdbg_RX_SDA_MOSI_PIN) */
                }

                if (0u != (UARTdbg_UART_TX_PIN_ENABLE & uartEnableMask))
                {
                #if (UARTdbg_TX_SCL_MISO_PIN)
                    hsiomSel[UARTdbg_TX_SCL_MISO_PIN_INDEX] = UARTdbg_TX_SCL_MISO_HSIOM_SEL_UART;
                    pinsDm  [UARTdbg_TX_SCL_MISO_PIN_INDEX] = UARTdbg_PIN_DM_STRONG;
                    
                    /* Disable input buffer */
                    pinsInBuf |= UARTdbg_TX_SCL_MISO_PIN_MASK;
                #endif /* (UARTdbg_TX_SCL_MISO_PIN) */
                }

            #if !(UARTdbg_CY_SCBIP_V0 || UARTdbg_CY_SCBIP_V1)
                if (UARTdbg_UART_MODE_STD == subMode)
                {
                    if (0u != (UARTdbg_UART_CTS_PIN_ENABLE & uartEnableMask))
                    {
                        /* CTS input is multiplexed with SCLK */
                    #if (UARTdbg_CTS_SCLK_PIN)
                        hsiomSel[UARTdbg_CTS_SCLK_PIN_INDEX] = UARTdbg_CTS_SCLK_HSIOM_SEL_UART;
                        pinsDm  [UARTdbg_CTS_SCLK_PIN_INDEX] = UARTdbg_PIN_DM_DIG_HIZ;
                    #endif /* (UARTdbg_CTS_SCLK_PIN) */
                    }

                    if (0u != (UARTdbg_UART_RTS_PIN_ENABLE & uartEnableMask))
                    {
                        /* RTS output is multiplexed with SS0 */
                    #if (UARTdbg_RTS_SS0_PIN)
                        hsiomSel[UARTdbg_RTS_SS0_PIN_INDEX] = UARTdbg_RTS_SS0_HSIOM_SEL_UART;
                        pinsDm  [UARTdbg_RTS_SS0_PIN_INDEX] = UARTdbg_PIN_DM_STRONG;
                        
                        /* Disable input buffer */
                        pinsInBuf |= UARTdbg_RTS_SS0_PIN_MASK;
                    #endif /* (UARTdbg_RTS_SS0_PIN) */
                    }
                }
            #endif /* !(UARTdbg_CY_SCBIP_V0 || UARTdbg_CY_SCBIP_V1) */
            }
        }
    #endif /* (!UARTdbg_CY_SCBIP_V1) */

    /* Configure pins: set HSIOM, DM and InputBufEnable */
    /* Note: the DR register settings do not effect the pin output if HSIOM is other than GPIO */

    #if (UARTdbg_RX_SDA_MOSI_PIN)
        UARTdbg_SET_HSIOM_SEL(UARTdbg_RX_SDA_MOSI_HSIOM_REG,
                                       UARTdbg_RX_SDA_MOSI_HSIOM_MASK,
                                       UARTdbg_RX_SDA_MOSI_HSIOM_POS,
                                        hsiomSel[UARTdbg_RX_SDA_MOSI_PIN_INDEX]);

        UARTdbg_uart_rx_i2c_sda_spi_mosi_SetDriveMode((uint8) pinsDm[UARTdbg_RX_SDA_MOSI_PIN_INDEX]);

        #if (!UARTdbg_CY_SCBIP_V1)
            UARTdbg_SET_INP_DIS(UARTdbg_uart_rx_i2c_sda_spi_mosi_INP_DIS,
                                         UARTdbg_uart_rx_i2c_sda_spi_mosi_MASK,
                                         (0u != (pinsInBuf & UARTdbg_RX_SDA_MOSI_PIN_MASK)));
        #endif /* (!UARTdbg_CY_SCBIP_V1) */
    
    #elif (UARTdbg_RX_WAKE_SDA_MOSI_PIN)
        UARTdbg_SET_HSIOM_SEL(UARTdbg_RX_WAKE_SDA_MOSI_HSIOM_REG,
                                       UARTdbg_RX_WAKE_SDA_MOSI_HSIOM_MASK,
                                       UARTdbg_RX_WAKE_SDA_MOSI_HSIOM_POS,
                                       hsiomSel[UARTdbg_RX_WAKE_SDA_MOSI_PIN_INDEX]);

        UARTdbg_uart_rx_wake_i2c_sda_spi_mosi_SetDriveMode((uint8)
                                                               pinsDm[UARTdbg_RX_WAKE_SDA_MOSI_PIN_INDEX]);

        UARTdbg_SET_INP_DIS(UARTdbg_uart_rx_wake_i2c_sda_spi_mosi_INP_DIS,
                                     UARTdbg_uart_rx_wake_i2c_sda_spi_mosi_MASK,
                                     (0u != (pinsInBuf & UARTdbg_RX_WAKE_SDA_MOSI_PIN_MASK)));

         /* Set interrupt on falling edge */
        UARTdbg_SET_INCFG_TYPE(UARTdbg_RX_WAKE_SDA_MOSI_INTCFG_REG,
                                        UARTdbg_RX_WAKE_SDA_MOSI_INTCFG_TYPE_MASK,
                                        UARTdbg_RX_WAKE_SDA_MOSI_INTCFG_TYPE_POS,
                                        UARTdbg_INTCFG_TYPE_FALLING_EDGE);
    #else
    #endif /* (UARTdbg_RX_WAKE_SDA_MOSI_PIN) */

    #if (UARTdbg_TX_SCL_MISO_PIN)
        UARTdbg_SET_HSIOM_SEL(UARTdbg_TX_SCL_MISO_HSIOM_REG,
                                       UARTdbg_TX_SCL_MISO_HSIOM_MASK,
                                       UARTdbg_TX_SCL_MISO_HSIOM_POS,
                                        hsiomSel[UARTdbg_TX_SCL_MISO_PIN_INDEX]);

        UARTdbg_uart_tx_i2c_scl_spi_miso_SetDriveMode((uint8) pinsDm[UARTdbg_TX_SCL_MISO_PIN_INDEX]);

    #if (!UARTdbg_CY_SCBIP_V1)
        UARTdbg_SET_INP_DIS(UARTdbg_uart_tx_i2c_scl_spi_miso_INP_DIS,
                                     UARTdbg_uart_tx_i2c_scl_spi_miso_MASK,
                                    (0u != (pinsInBuf & UARTdbg_TX_SCL_MISO_PIN_MASK)));
    #endif /* (!UARTdbg_CY_SCBIP_V1) */
    #endif /* (UARTdbg_RX_SDA_MOSI_PIN) */

    #if (UARTdbg_CTS_SCLK_PIN)
        UARTdbg_SET_HSIOM_SEL(UARTdbg_CTS_SCLK_HSIOM_REG,
                                       UARTdbg_CTS_SCLK_HSIOM_MASK,
                                       UARTdbg_CTS_SCLK_HSIOM_POS,
                                       hsiomSel[UARTdbg_CTS_SCLK_PIN_INDEX]);

        UARTdbg_uart_cts_spi_sclk_SetDriveMode((uint8) pinsDm[UARTdbg_CTS_SCLK_PIN_INDEX]);

        UARTdbg_SET_INP_DIS(UARTdbg_uart_cts_spi_sclk_INP_DIS,
                                     UARTdbg_uart_cts_spi_sclk_MASK,
                                     (0u != (pinsInBuf & UARTdbg_CTS_SCLK_PIN_MASK)));
    #endif /* (UARTdbg_CTS_SCLK_PIN) */

    #if (UARTdbg_RTS_SS0_PIN)
        UARTdbg_SET_HSIOM_SEL(UARTdbg_RTS_SS0_HSIOM_REG,
                                       UARTdbg_RTS_SS0_HSIOM_MASK,
                                       UARTdbg_RTS_SS0_HSIOM_POS,
                                       hsiomSel[UARTdbg_RTS_SS0_PIN_INDEX]);

        UARTdbg_uart_rts_spi_ss0_SetDriveMode((uint8) pinsDm[UARTdbg_RTS_SS0_PIN_INDEX]);

        UARTdbg_SET_INP_DIS(UARTdbg_uart_rts_spi_ss0_INP_DIS,
                                     UARTdbg_uart_rts_spi_ss0_MASK,
                                     (0u != (pinsInBuf & UARTdbg_RTS_SS0_PIN_MASK)));
    #endif /* (UARTdbg_RTS_SS0_PIN) */

    #if (UARTdbg_SS1_PIN)
        UARTdbg_SET_HSIOM_SEL(UARTdbg_SS1_HSIOM_REG,
                                       UARTdbg_SS1_HSIOM_MASK,
                                       UARTdbg_SS1_HSIOM_POS,
                                       hsiomSel[UARTdbg_SS1_PIN_INDEX]);

        UARTdbg_spi_ss1_SetDriveMode((uint8) pinsDm[UARTdbg_SS1_PIN_INDEX]);

        UARTdbg_SET_INP_DIS(UARTdbg_spi_ss1_INP_DIS,
                                     UARTdbg_spi_ss1_MASK,
                                     (0u != (pinsInBuf & UARTdbg_SS1_PIN_MASK)));
    #endif /* (UARTdbg_SS1_PIN) */

    #if (UARTdbg_SS2_PIN)
        UARTdbg_SET_HSIOM_SEL(UARTdbg_SS2_HSIOM_REG,
                                       UARTdbg_SS2_HSIOM_MASK,
                                       UARTdbg_SS2_HSIOM_POS,
                                       hsiomSel[UARTdbg_SS2_PIN_INDEX]);

        UARTdbg_spi_ss2_SetDriveMode((uint8) pinsDm[UARTdbg_SS2_PIN_INDEX]);

        UARTdbg_SET_INP_DIS(UARTdbg_spi_ss2_INP_DIS,
                                     UARTdbg_spi_ss2_MASK,
                                     (0u != (pinsInBuf & UARTdbg_SS2_PIN_MASK)));
    #endif /* (UARTdbg_SS2_PIN) */

    #if (UARTdbg_SS3_PIN)
        UARTdbg_SET_HSIOM_SEL(UARTdbg_SS3_HSIOM_REG,
                                       UARTdbg_SS3_HSIOM_MASK,
                                       UARTdbg_SS3_HSIOM_POS,
                                       hsiomSel[UARTdbg_SS3_PIN_INDEX]);

        UARTdbg_spi_ss3_SetDriveMode((uint8) pinsDm[UARTdbg_SS3_PIN_INDEX]);

        UARTdbg_SET_INP_DIS(UARTdbg_spi_ss3_INP_DIS,
                                     UARTdbg_spi_ss3_MASK,
                                     (0u != (pinsInBuf & UARTdbg_SS3_PIN_MASK)));
    #endif /* (UARTdbg_SS3_PIN) */
    }

#endif /* (UARTdbg_SCB_MODE_UNCONFIG_CONST_CFG) */


#if (UARTdbg_CY_SCBIP_V0 || UARTdbg_CY_SCBIP_V1)
    /*******************************************************************************
    * Function Name: UARTdbg_I2CSlaveNackGeneration
    ****************************************************************************//**
    *
    *  Sets command to generate NACK to the address or data.
    *
    *******************************************************************************/
    void UARTdbg_I2CSlaveNackGeneration(void)
    {
        /* Check for EC_AM toggle condition: EC_AM and clock stretching for address are enabled */
        if ((0u != (UARTdbg_CTRL_REG & UARTdbg_CTRL_EC_AM_MODE)) &&
            (0u == (UARTdbg_I2C_CTRL_REG & UARTdbg_I2C_CTRL_S_NOT_READY_ADDR_NACK)))
        {
            /* Toggle EC_AM before NACK generation */
            UARTdbg_CTRL_REG &= ~UARTdbg_CTRL_EC_AM_MODE;
            UARTdbg_CTRL_REG |=  UARTdbg_CTRL_EC_AM_MODE;
        }

        UARTdbg_I2C_SLAVE_CMD_REG = UARTdbg_I2C_SLAVE_CMD_S_NACK;
    }
#endif /* (UARTdbg_CY_SCBIP_V0 || UARTdbg_CY_SCBIP_V1) */


/* [] END OF FILE */
