/***************************************************************************//**
* \file UARTdbg_PM.c
* \version 4.0
*
* \brief
*  This file provides the source code to the Power Management support for
*  the SCB Component.
*
* Note:
*
********************************************************************************
* \copyright
* Copyright 2013-2017, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "UARTdbg.h"
#include "UARTdbg_PVT.h"

#if(UARTdbg_SCB_MODE_I2C_INC)
    #include "UARTdbg_I2C_PVT.h"
#endif /* (UARTdbg_SCB_MODE_I2C_INC) */

#if(UARTdbg_SCB_MODE_EZI2C_INC)
    #include "UARTdbg_EZI2C_PVT.h"
#endif /* (UARTdbg_SCB_MODE_EZI2C_INC) */

#if(UARTdbg_SCB_MODE_SPI_INC || UARTdbg_SCB_MODE_UART_INC)
    #include "UARTdbg_SPI_UART_PVT.h"
#endif /* (UARTdbg_SCB_MODE_SPI_INC || UARTdbg_SCB_MODE_UART_INC) */


/***************************************
*   Backup Structure declaration
***************************************/

#if(UARTdbg_SCB_MODE_UNCONFIG_CONST_CFG || \
   (UARTdbg_SCB_MODE_I2C_CONST_CFG   && (!UARTdbg_I2C_WAKE_ENABLE_CONST))   || \
   (UARTdbg_SCB_MODE_EZI2C_CONST_CFG && (!UARTdbg_EZI2C_WAKE_ENABLE_CONST)) || \
   (UARTdbg_SCB_MODE_SPI_CONST_CFG   && (!UARTdbg_SPI_WAKE_ENABLE_CONST))   || \
   (UARTdbg_SCB_MODE_UART_CONST_CFG  && (!UARTdbg_UART_WAKE_ENABLE_CONST)))

    UARTdbg_BACKUP_STRUCT UARTdbg_backup =
    {
        0u, /* enableState */
    };
#endif


/*******************************************************************************
* Function Name: UARTdbg_Sleep
****************************************************************************//**
*
*  Prepares the UARTdbg component to enter Deep Sleep.
*  The “Enable wakeup from Deep Sleep Mode” selection has an influence on this 
*  function implementation:
*  - Checked: configures the component to be wakeup source from Deep Sleep.
*  - Unchecked: stores the current component state (enabled or disabled) and 
*    disables the component. See SCB_Stop() function for details about component 
*    disabling.
*
*  Call the UARTdbg_Sleep() function before calling the 
*  CyPmSysDeepSleep() function. 
*  Refer to the PSoC Creator System Reference Guide for more information about 
*  power management functions and Low power section of this document for the 
*  selected mode.
*
*  This function should not be called before entering Sleep.
*
*******************************************************************************/
void UARTdbg_Sleep(void)
{
#if(UARTdbg_SCB_MODE_UNCONFIG_CONST_CFG)

    if(UARTdbg_SCB_WAKE_ENABLE_CHECK)
    {
        if(UARTdbg_SCB_MODE_I2C_RUNTM_CFG)
        {
            UARTdbg_I2CSaveConfig();
        }
        else if(UARTdbg_SCB_MODE_EZI2C_RUNTM_CFG)
        {
            UARTdbg_EzI2CSaveConfig();
        }
    #if(!UARTdbg_CY_SCBIP_V1)
        else if(UARTdbg_SCB_MODE_SPI_RUNTM_CFG)
        {
            UARTdbg_SpiSaveConfig();
        }
        else if(UARTdbg_SCB_MODE_UART_RUNTM_CFG)
        {
            UARTdbg_UartSaveConfig();
        }
    #endif /* (!UARTdbg_CY_SCBIP_V1) */
        else
        {
            /* Unknown mode */
        }
    }
    else
    {
        UARTdbg_backup.enableState = (uint8) UARTdbg_GET_CTRL_ENABLED;

        if(0u != UARTdbg_backup.enableState)
        {
            UARTdbg_Stop();
        }
    }

#else

    #if (UARTdbg_SCB_MODE_I2C_CONST_CFG && UARTdbg_I2C_WAKE_ENABLE_CONST)
        UARTdbg_I2CSaveConfig();

    #elif (UARTdbg_SCB_MODE_EZI2C_CONST_CFG && UARTdbg_EZI2C_WAKE_ENABLE_CONST)
        UARTdbg_EzI2CSaveConfig();

    #elif (UARTdbg_SCB_MODE_SPI_CONST_CFG && UARTdbg_SPI_WAKE_ENABLE_CONST)
        UARTdbg_SpiSaveConfig();

    #elif (UARTdbg_SCB_MODE_UART_CONST_CFG && UARTdbg_UART_WAKE_ENABLE_CONST)
        UARTdbg_UartSaveConfig();

    #else

        UARTdbg_backup.enableState = (uint8) UARTdbg_GET_CTRL_ENABLED;

        if(0u != UARTdbg_backup.enableState)
        {
            UARTdbg_Stop();
        }

    #endif /* defined (UARTdbg_SCB_MODE_I2C_CONST_CFG) && (UARTdbg_I2C_WAKE_ENABLE_CONST) */

#endif /* (UARTdbg_SCB_MODE_UNCONFIG_CONST_CFG) */
}


/*******************************************************************************
* Function Name: UARTdbg_Wakeup
****************************************************************************//**
*
*  Prepares the UARTdbg component for Active mode operation after 
*  Deep Sleep.
*  The “Enable wakeup from Deep Sleep Mode” selection has influence on this 
*  function implementation:
*  - Checked: restores the component Active mode configuration.
*  - Unchecked: enables the component if it was enabled before enter Deep Sleep.
*
*  This function should not be called after exiting Sleep.
*
*  \sideeffect
*   Calling the UARTdbg_Wakeup() function without first calling the 
*   UARTdbg_Sleep() function may produce unexpected behavior.
*
*******************************************************************************/
void UARTdbg_Wakeup(void)
{
#if(UARTdbg_SCB_MODE_UNCONFIG_CONST_CFG)

    if(UARTdbg_SCB_WAKE_ENABLE_CHECK)
    {
        if(UARTdbg_SCB_MODE_I2C_RUNTM_CFG)
        {
            UARTdbg_I2CRestoreConfig();
        }
        else if(UARTdbg_SCB_MODE_EZI2C_RUNTM_CFG)
        {
            UARTdbg_EzI2CRestoreConfig();
        }
    #if(!UARTdbg_CY_SCBIP_V1)
        else if(UARTdbg_SCB_MODE_SPI_RUNTM_CFG)
        {
            UARTdbg_SpiRestoreConfig();
        }
        else if(UARTdbg_SCB_MODE_UART_RUNTM_CFG)
        {
            UARTdbg_UartRestoreConfig();
        }
    #endif /* (!UARTdbg_CY_SCBIP_V1) */
        else
        {
            /* Unknown mode */
        }
    }
    else
    {
        if(0u != UARTdbg_backup.enableState)
        {
            UARTdbg_Enable();
        }
    }

#else

    #if (UARTdbg_SCB_MODE_I2C_CONST_CFG  && UARTdbg_I2C_WAKE_ENABLE_CONST)
        UARTdbg_I2CRestoreConfig();

    #elif (UARTdbg_SCB_MODE_EZI2C_CONST_CFG && UARTdbg_EZI2C_WAKE_ENABLE_CONST)
        UARTdbg_EzI2CRestoreConfig();

    #elif (UARTdbg_SCB_MODE_SPI_CONST_CFG && UARTdbg_SPI_WAKE_ENABLE_CONST)
        UARTdbg_SpiRestoreConfig();

    #elif (UARTdbg_SCB_MODE_UART_CONST_CFG && UARTdbg_UART_WAKE_ENABLE_CONST)
        UARTdbg_UartRestoreConfig();

    #else

        if(0u != UARTdbg_backup.enableState)
        {
            UARTdbg_Enable();
        }

    #endif /* (UARTdbg_I2C_WAKE_ENABLE_CONST) */

#endif /* (UARTdbg_SCB_MODE_UNCONFIG_CONST_CFG) */
}


/* [] END OF FILE */
