/***************************************************************************//**
* \file UARTdbg_SPI_UART_INT.c
* \version 4.0
*
* \brief
*  This file provides the source code to the Interrupt Service Routine for
*  the SCB Component in SPI and UART modes.
*
* Note:
*
********************************************************************************
* \copyright
* Copyright 2013-2017, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "UARTdbg_PVT.h"
#include "UARTdbg_SPI_UART_PVT.h"
#include "cyapicallbacks.h"

#if (UARTdbg_SCB_IRQ_INTERNAL)
/*******************************************************************************
* Function Name: UARTdbg_SPI_UART_ISR
****************************************************************************//**
*
*  Handles the Interrupt Service Routine for the SCB SPI or UART modes.
*
*******************************************************************************/
CY_ISR(UARTdbg_SPI_UART_ISR)
{
#if (UARTdbg_INTERNAL_RX_SW_BUFFER_CONST)
    uint32 locHead;
#endif /* (UARTdbg_INTERNAL_RX_SW_BUFFER_CONST) */

#if (UARTdbg_INTERNAL_TX_SW_BUFFER_CONST)
    uint32 locTail;
#endif /* (UARTdbg_INTERNAL_TX_SW_BUFFER_CONST) */

#ifdef UARTdbg_SPI_UART_ISR_ENTRY_CALLBACK
    UARTdbg_SPI_UART_ISR_EntryCallback();
#endif /* UARTdbg_SPI_UART_ISR_ENTRY_CALLBACK */

    if (NULL != UARTdbg_customIntrHandler)
    {
        UARTdbg_customIntrHandler();
    }

    #if(UARTdbg_CHECK_SPI_WAKE_ENABLE)
    {
        /* Clear SPI wakeup source */
        UARTdbg_ClearSpiExtClkInterruptSource(UARTdbg_INTR_SPI_EC_WAKE_UP);
    }
    #endif

    #if (UARTdbg_CHECK_RX_SW_BUFFER)
    {
        if (UARTdbg_CHECK_INTR_RX_MASKED(UARTdbg_INTR_RX_NOT_EMPTY))
        {
            do
            {
                /* Move local head index */
                locHead = (UARTdbg_rxBufferHead + 1u);

                /* Adjust local head index */
                if (UARTdbg_INTERNAL_RX_BUFFER_SIZE == locHead)
                {
                    locHead = 0u;
                }

                if (locHead == UARTdbg_rxBufferTail)
                {
                    #if (UARTdbg_CHECK_UART_RTS_CONTROL_FLOW)
                    {
                        /* There is no space in the software buffer - disable the
                        * RX Not Empty interrupt source. The data elements are
                        * still being received into the RX FIFO until the RTS signal
                        * stops the transmitter. After the data element is read from the
                        * buffer, the RX Not Empty interrupt source is enabled to
                        * move the next data element in the software buffer.
                        */
                        UARTdbg_INTR_RX_MASK_REG &= ~UARTdbg_INTR_RX_NOT_EMPTY;
                        break;
                    }
                    #else
                    {
                        /* Overflow: through away received data element */
                        (void) UARTdbg_RX_FIFO_RD_REG;
                        UARTdbg_rxBufferOverflow = (uint8) UARTdbg_INTR_RX_OVERFLOW;
                    }
                    #endif
                }
                else
                {
                    /* Store received data */
                    UARTdbg_PutWordInRxBuffer(locHead, UARTdbg_RX_FIFO_RD_REG);

                    /* Move head index */
                    UARTdbg_rxBufferHead = locHead;
                }
            }
            while(0u != UARTdbg_GET_RX_FIFO_ENTRIES);

            UARTdbg_ClearRxInterruptSource(UARTdbg_INTR_RX_NOT_EMPTY);
        }
    }
    #endif


    #if (UARTdbg_CHECK_TX_SW_BUFFER)
    {
        if (UARTdbg_CHECK_INTR_TX_MASKED(UARTdbg_INTR_TX_NOT_FULL))
        {
            do
            {
                /* Check for room in TX software buffer */
                if (UARTdbg_txBufferHead != UARTdbg_txBufferTail)
                {
                    /* Move local tail index */
                    locTail = (UARTdbg_txBufferTail + 1u);

                    /* Adjust local tail index */
                    if (UARTdbg_TX_BUFFER_SIZE == locTail)
                    {
                        locTail = 0u;
                    }

                    /* Put data into TX FIFO */
                    UARTdbg_TX_FIFO_WR_REG = UARTdbg_GetWordFromTxBuffer(locTail);

                    /* Move tail index */
                    UARTdbg_txBufferTail = locTail;
                }
                else
                {
                    /* TX software buffer is empty: complete transfer */
                    UARTdbg_DISABLE_INTR_TX(UARTdbg_INTR_TX_NOT_FULL);
                    break;
                }
            }
            while (UARTdbg_SPI_UART_FIFO_SIZE != UARTdbg_GET_TX_FIFO_ENTRIES);

            UARTdbg_ClearTxInterruptSource(UARTdbg_INTR_TX_NOT_FULL);
        }
    }
    #endif

#ifdef UARTdbg_SPI_UART_ISR_EXIT_CALLBACK
    UARTdbg_SPI_UART_ISR_ExitCallback();
#endif /* UARTdbg_SPI_UART_ISR_EXIT_CALLBACK */

}

#endif /* (UARTdbg_SCB_IRQ_INTERNAL) */


/* [] END OF FILE */
