/*******************************************************************************
* File Name: pwm_LED_PM.c
* Version 3.30
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "pwm_LED.h"

static pwm_LED_backupStruct pwm_LED_backup;


/*******************************************************************************
* Function Name: pwm_LED_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  pwm_LED_backup:  Variables of this global structure are modified to
*  store the values of non retention configuration registers when Sleep() API is
*  called.
*
*******************************************************************************/
void pwm_LED_SaveConfig(void) 
{

    #if(!pwm_LED_UsingFixedFunction)
        #if(!pwm_LED_PWMModeIsCenterAligned)
            pwm_LED_backup.PWMPeriod = pwm_LED_ReadPeriod();
        #endif /* (!pwm_LED_PWMModeIsCenterAligned) */
        pwm_LED_backup.PWMUdb = pwm_LED_ReadCounter();
        #if (pwm_LED_UseStatus)
            pwm_LED_backup.InterruptMaskValue = pwm_LED_STATUS_MASK;
        #endif /* (pwm_LED_UseStatus) */

        #if(pwm_LED_DeadBandMode == pwm_LED__B_PWM__DBM_256_CLOCKS || \
            pwm_LED_DeadBandMode == pwm_LED__B_PWM__DBM_2_4_CLOCKS)
            pwm_LED_backup.PWMdeadBandValue = pwm_LED_ReadDeadTime();
        #endif /*  deadband count is either 2-4 clocks or 256 clocks */

        #if(pwm_LED_KillModeMinTime)
             pwm_LED_backup.PWMKillCounterPeriod = pwm_LED_ReadKillTime();
        #endif /* (pwm_LED_KillModeMinTime) */

        #if(pwm_LED_UseControl)
            pwm_LED_backup.PWMControlRegister = pwm_LED_ReadControlRegister();
        #endif /* (pwm_LED_UseControl) */
    #endif  /* (!pwm_LED_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: pwm_LED_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  pwm_LED_backup:  Variables of this global structure are used to
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void pwm_LED_RestoreConfig(void) 
{
        #if(!pwm_LED_UsingFixedFunction)
            #if(!pwm_LED_PWMModeIsCenterAligned)
                pwm_LED_WritePeriod(pwm_LED_backup.PWMPeriod);
            #endif /* (!pwm_LED_PWMModeIsCenterAligned) */

            pwm_LED_WriteCounter(pwm_LED_backup.PWMUdb);

            #if (pwm_LED_UseStatus)
                pwm_LED_STATUS_MASK = pwm_LED_backup.InterruptMaskValue;
            #endif /* (pwm_LED_UseStatus) */

            #if(pwm_LED_DeadBandMode == pwm_LED__B_PWM__DBM_256_CLOCKS || \
                pwm_LED_DeadBandMode == pwm_LED__B_PWM__DBM_2_4_CLOCKS)
                pwm_LED_WriteDeadTime(pwm_LED_backup.PWMdeadBandValue);
            #endif /* deadband count is either 2-4 clocks or 256 clocks */

            #if(pwm_LED_KillModeMinTime)
                pwm_LED_WriteKillTime(pwm_LED_backup.PWMKillCounterPeriod);
            #endif /* (pwm_LED_KillModeMinTime) */

            #if(pwm_LED_UseControl)
                pwm_LED_WriteControlRegister(pwm_LED_backup.PWMControlRegister);
            #endif /* (pwm_LED_UseControl) */
        #endif  /* (!pwm_LED_UsingFixedFunction) */
    }


/*******************************************************************************
* Function Name: pwm_LED_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves the user configuration. Should be called
*  just prior to entering sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  pwm_LED_backup.PWMEnableState:  Is modified depending on the enable
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void pwm_LED_Sleep(void) 
{
    #if(pwm_LED_UseControl)
        if(pwm_LED_CTRL_ENABLE == (pwm_LED_CONTROL & pwm_LED_CTRL_ENABLE))
        {
            /*Component is enabled */
            pwm_LED_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            pwm_LED_backup.PWMEnableState = 0u;
        }
    #endif /* (pwm_LED_UseControl) */

    /* Stop component */
    pwm_LED_Stop();

    /* Save registers configuration */
    pwm_LED_SaveConfig();
}


/*******************************************************************************
* Function Name: pwm_LED_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called just after
*  awaking from sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  pwm_LED_backup.pwmEnable:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void pwm_LED_Wakeup(void) 
{
     /* Restore registers values */
    pwm_LED_RestoreConfig();

    if(pwm_LED_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        pwm_LED_Enable();
    } /* Do nothing if component's block was disabled before */

}


/* [] END OF FILE */
