/*******************************************************************************
* File Name: pwm_prop_PM.c
* Version 3.30
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "pwm_prop.h"

static pwm_prop_backupStruct pwm_prop_backup;


/*******************************************************************************
* Function Name: pwm_prop_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  pwm_prop_backup:  Variables of this global structure are modified to
*  store the values of non retention configuration registers when Sleep() API is
*  called.
*
*******************************************************************************/
void pwm_prop_SaveConfig(void) 
{

    #if(!pwm_prop_UsingFixedFunction)
        #if(!pwm_prop_PWMModeIsCenterAligned)
            pwm_prop_backup.PWMPeriod = pwm_prop_ReadPeriod();
        #endif /* (!pwm_prop_PWMModeIsCenterAligned) */
        pwm_prop_backup.PWMUdb = pwm_prop_ReadCounter();
        #if (pwm_prop_UseStatus)
            pwm_prop_backup.InterruptMaskValue = pwm_prop_STATUS_MASK;
        #endif /* (pwm_prop_UseStatus) */

        #if(pwm_prop_DeadBandMode == pwm_prop__B_PWM__DBM_256_CLOCKS || \
            pwm_prop_DeadBandMode == pwm_prop__B_PWM__DBM_2_4_CLOCKS)
            pwm_prop_backup.PWMdeadBandValue = pwm_prop_ReadDeadTime();
        #endif /*  deadband count is either 2-4 clocks or 256 clocks */

        #if(pwm_prop_KillModeMinTime)
             pwm_prop_backup.PWMKillCounterPeriod = pwm_prop_ReadKillTime();
        #endif /* (pwm_prop_KillModeMinTime) */

        #if(pwm_prop_UseControl)
            pwm_prop_backup.PWMControlRegister = pwm_prop_ReadControlRegister();
        #endif /* (pwm_prop_UseControl) */
    #endif  /* (!pwm_prop_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: pwm_prop_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  pwm_prop_backup:  Variables of this global structure are used to
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void pwm_prop_RestoreConfig(void) 
{
        #if(!pwm_prop_UsingFixedFunction)
            #if(!pwm_prop_PWMModeIsCenterAligned)
                pwm_prop_WritePeriod(pwm_prop_backup.PWMPeriod);
            #endif /* (!pwm_prop_PWMModeIsCenterAligned) */

            pwm_prop_WriteCounter(pwm_prop_backup.PWMUdb);

            #if (pwm_prop_UseStatus)
                pwm_prop_STATUS_MASK = pwm_prop_backup.InterruptMaskValue;
            #endif /* (pwm_prop_UseStatus) */

            #if(pwm_prop_DeadBandMode == pwm_prop__B_PWM__DBM_256_CLOCKS || \
                pwm_prop_DeadBandMode == pwm_prop__B_PWM__DBM_2_4_CLOCKS)
                pwm_prop_WriteDeadTime(pwm_prop_backup.PWMdeadBandValue);
            #endif /* deadband count is either 2-4 clocks or 256 clocks */

            #if(pwm_prop_KillModeMinTime)
                pwm_prop_WriteKillTime(pwm_prop_backup.PWMKillCounterPeriod);
            #endif /* (pwm_prop_KillModeMinTime) */

            #if(pwm_prop_UseControl)
                pwm_prop_WriteControlRegister(pwm_prop_backup.PWMControlRegister);
            #endif /* (pwm_prop_UseControl) */
        #endif  /* (!pwm_prop_UsingFixedFunction) */
    }


/*******************************************************************************
* Function Name: pwm_prop_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves the user configuration. Should be called
*  just prior to entering sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  pwm_prop_backup.PWMEnableState:  Is modified depending on the enable
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void pwm_prop_Sleep(void) 
{
    #if(pwm_prop_UseControl)
        if(pwm_prop_CTRL_ENABLE == (pwm_prop_CONTROL & pwm_prop_CTRL_ENABLE))
        {
            /*Component is enabled */
            pwm_prop_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            pwm_prop_backup.PWMEnableState = 0u;
        }
    #endif /* (pwm_prop_UseControl) */

    /* Stop component */
    pwm_prop_Stop();

    /* Save registers configuration */
    pwm_prop_SaveConfig();
}


/*******************************************************************************
* Function Name: pwm_prop_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called just after
*  awaking from sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  pwm_prop_backup.pwmEnable:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void pwm_prop_Wakeup(void) 
{
     /* Restore registers values */
    pwm_prop_RestoreConfig();

    if(pwm_prop_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        pwm_prop_Enable();
    } /* Do nothing if component's block was disabled before */

}


/* [] END OF FILE */
