/*******************************************************************************
* File Name: pwm_Vibrator_PM.c
* Version 3.30
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "pwm_Vibrator.h"

static pwm_Vibrator_backupStruct pwm_Vibrator_backup;


/*******************************************************************************
* Function Name: pwm_Vibrator_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  pwm_Vibrator_backup:  Variables of this global structure are modified to
*  store the values of non retention configuration registers when Sleep() API is
*  called.
*
*******************************************************************************/
void pwm_Vibrator_SaveConfig(void) 
{

    #if(!pwm_Vibrator_UsingFixedFunction)
        #if(!pwm_Vibrator_PWMModeIsCenterAligned)
            pwm_Vibrator_backup.PWMPeriod = pwm_Vibrator_ReadPeriod();
        #endif /* (!pwm_Vibrator_PWMModeIsCenterAligned) */
        pwm_Vibrator_backup.PWMUdb = pwm_Vibrator_ReadCounter();
        #if (pwm_Vibrator_UseStatus)
            pwm_Vibrator_backup.InterruptMaskValue = pwm_Vibrator_STATUS_MASK;
        #endif /* (pwm_Vibrator_UseStatus) */

        #if(pwm_Vibrator_DeadBandMode == pwm_Vibrator__B_PWM__DBM_256_CLOCKS || \
            pwm_Vibrator_DeadBandMode == pwm_Vibrator__B_PWM__DBM_2_4_CLOCKS)
            pwm_Vibrator_backup.PWMdeadBandValue = pwm_Vibrator_ReadDeadTime();
        #endif /*  deadband count is either 2-4 clocks or 256 clocks */

        #if(pwm_Vibrator_KillModeMinTime)
             pwm_Vibrator_backup.PWMKillCounterPeriod = pwm_Vibrator_ReadKillTime();
        #endif /* (pwm_Vibrator_KillModeMinTime) */

        #if(pwm_Vibrator_UseControl)
            pwm_Vibrator_backup.PWMControlRegister = pwm_Vibrator_ReadControlRegister();
        #endif /* (pwm_Vibrator_UseControl) */
    #endif  /* (!pwm_Vibrator_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: pwm_Vibrator_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  pwm_Vibrator_backup:  Variables of this global structure are used to
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void pwm_Vibrator_RestoreConfig(void) 
{
        #if(!pwm_Vibrator_UsingFixedFunction)
            #if(!pwm_Vibrator_PWMModeIsCenterAligned)
                pwm_Vibrator_WritePeriod(pwm_Vibrator_backup.PWMPeriod);
            #endif /* (!pwm_Vibrator_PWMModeIsCenterAligned) */

            pwm_Vibrator_WriteCounter(pwm_Vibrator_backup.PWMUdb);

            #if (pwm_Vibrator_UseStatus)
                pwm_Vibrator_STATUS_MASK = pwm_Vibrator_backup.InterruptMaskValue;
            #endif /* (pwm_Vibrator_UseStatus) */

            #if(pwm_Vibrator_DeadBandMode == pwm_Vibrator__B_PWM__DBM_256_CLOCKS || \
                pwm_Vibrator_DeadBandMode == pwm_Vibrator__B_PWM__DBM_2_4_CLOCKS)
                pwm_Vibrator_WriteDeadTime(pwm_Vibrator_backup.PWMdeadBandValue);
            #endif /* deadband count is either 2-4 clocks or 256 clocks */

            #if(pwm_Vibrator_KillModeMinTime)
                pwm_Vibrator_WriteKillTime(pwm_Vibrator_backup.PWMKillCounterPeriod);
            #endif /* (pwm_Vibrator_KillModeMinTime) */

            #if(pwm_Vibrator_UseControl)
                pwm_Vibrator_WriteControlRegister(pwm_Vibrator_backup.PWMControlRegister);
            #endif /* (pwm_Vibrator_UseControl) */
        #endif  /* (!pwm_Vibrator_UsingFixedFunction) */
    }


/*******************************************************************************
* Function Name: pwm_Vibrator_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves the user configuration. Should be called
*  just prior to entering sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  pwm_Vibrator_backup.PWMEnableState:  Is modified depending on the enable
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void pwm_Vibrator_Sleep(void) 
{
    #if(pwm_Vibrator_UseControl)
        if(pwm_Vibrator_CTRL_ENABLE == (pwm_Vibrator_CONTROL & pwm_Vibrator_CTRL_ENABLE))
        {
            /*Component is enabled */
            pwm_Vibrator_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            pwm_Vibrator_backup.PWMEnableState = 0u;
        }
    #endif /* (pwm_Vibrator_UseControl) */

    /* Stop component */
    pwm_Vibrator_Stop();

    /* Save registers configuration */
    pwm_Vibrator_SaveConfig();
}


/*******************************************************************************
* Function Name: pwm_Vibrator_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called just after
*  awaking from sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  pwm_Vibrator_backup.pwmEnable:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void pwm_Vibrator_Wakeup(void) 
{
     /* Restore registers values */
    pwm_Vibrator_RestoreConfig();

    if(pwm_Vibrator_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        pwm_Vibrator_Enable();
    } /* Do nothing if component's block was disabled before */

}


/* [] END OF FILE */
