/*******************************************************************************
* File Name: pwm_blue_PM.c
* Version 3.30
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "pwm_blue.h"

static pwm_blue_backupStruct pwm_blue_backup;


/*******************************************************************************
* Function Name: pwm_blue_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  pwm_blue_backup:  Variables of this global structure are modified to
*  store the values of non retention configuration registers when Sleep() API is
*  called.
*
*******************************************************************************/
void pwm_blue_SaveConfig(void) 
{

    #if(!pwm_blue_UsingFixedFunction)
        #if(!pwm_blue_PWMModeIsCenterAligned)
            pwm_blue_backup.PWMPeriod = pwm_blue_ReadPeriod();
        #endif /* (!pwm_blue_PWMModeIsCenterAligned) */
        pwm_blue_backup.PWMUdb = pwm_blue_ReadCounter();
        #if (pwm_blue_UseStatus)
            pwm_blue_backup.InterruptMaskValue = pwm_blue_STATUS_MASK;
        #endif /* (pwm_blue_UseStatus) */

        #if(pwm_blue_DeadBandMode == pwm_blue__B_PWM__DBM_256_CLOCKS || \
            pwm_blue_DeadBandMode == pwm_blue__B_PWM__DBM_2_4_CLOCKS)
            pwm_blue_backup.PWMdeadBandValue = pwm_blue_ReadDeadTime();
        #endif /*  deadband count is either 2-4 clocks or 256 clocks */

        #if(pwm_blue_KillModeMinTime)
             pwm_blue_backup.PWMKillCounterPeriod = pwm_blue_ReadKillTime();
        #endif /* (pwm_blue_KillModeMinTime) */

        #if(pwm_blue_UseControl)
            pwm_blue_backup.PWMControlRegister = pwm_blue_ReadControlRegister();
        #endif /* (pwm_blue_UseControl) */
    #endif  /* (!pwm_blue_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: pwm_blue_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  pwm_blue_backup:  Variables of this global structure are used to
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void pwm_blue_RestoreConfig(void) 
{
        #if(!pwm_blue_UsingFixedFunction)
            #if(!pwm_blue_PWMModeIsCenterAligned)
                pwm_blue_WritePeriod(pwm_blue_backup.PWMPeriod);
            #endif /* (!pwm_blue_PWMModeIsCenterAligned) */

            pwm_blue_WriteCounter(pwm_blue_backup.PWMUdb);

            #if (pwm_blue_UseStatus)
                pwm_blue_STATUS_MASK = pwm_blue_backup.InterruptMaskValue;
            #endif /* (pwm_blue_UseStatus) */

            #if(pwm_blue_DeadBandMode == pwm_blue__B_PWM__DBM_256_CLOCKS || \
                pwm_blue_DeadBandMode == pwm_blue__B_PWM__DBM_2_4_CLOCKS)
                pwm_blue_WriteDeadTime(pwm_blue_backup.PWMdeadBandValue);
            #endif /* deadband count is either 2-4 clocks or 256 clocks */

            #if(pwm_blue_KillModeMinTime)
                pwm_blue_WriteKillTime(pwm_blue_backup.PWMKillCounterPeriod);
            #endif /* (pwm_blue_KillModeMinTime) */

            #if(pwm_blue_UseControl)
                pwm_blue_WriteControlRegister(pwm_blue_backup.PWMControlRegister);
            #endif /* (pwm_blue_UseControl) */
        #endif  /* (!pwm_blue_UsingFixedFunction) */
    }


/*******************************************************************************
* Function Name: pwm_blue_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves the user configuration. Should be called
*  just prior to entering sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  pwm_blue_backup.PWMEnableState:  Is modified depending on the enable
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void pwm_blue_Sleep(void) 
{
    #if(pwm_blue_UseControl)
        if(pwm_blue_CTRL_ENABLE == (pwm_blue_CONTROL & pwm_blue_CTRL_ENABLE))
        {
            /*Component is enabled */
            pwm_blue_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            pwm_blue_backup.PWMEnableState = 0u;
        }
    #endif /* (pwm_blue_UseControl) */

    /* Stop component */
    pwm_blue_Stop();

    /* Save registers configuration */
    pwm_blue_SaveConfig();
}


/*******************************************************************************
* Function Name: pwm_blue_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called just after
*  awaking from sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  pwm_blue_backup.pwmEnable:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void pwm_blue_Wakeup(void) 
{
     /* Restore registers values */
    pwm_blue_RestoreConfig();

    if(pwm_blue_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        pwm_blue_Enable();
    } /* Do nothing if component's block was disabled before */

}


/* [] END OF FILE */
